# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.create_org_option import CreateOrgOption  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestCreateOrgOption(unittest.TestCase):
    """CreateOrgOption unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateOrgOption
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CreateOrgOption`
        """
        model = py_gitea_opensuse_org.models.create_org_option.CreateOrgOption()  # noqa: E501
        if include_optional :
            return CreateOrgOption(
                description = '', 
                full_name = '', 
                location = '', 
                repo_admin_change_team_access = True, 
                username = '', 
                visibility = 'public', 
                website = ''
            )
        else :
            return CreateOrgOption(
                username = '',
        )
        """

    def testCreateOrgOption(self):
        """Test CreateOrgOption"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.edit_repo_option import EditRepoOption  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestEditRepoOption(unittest.TestCase):
    """EditRepoOption unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EditRepoOption
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `EditRepoOption`
        """
        model = py_gitea_opensuse_org.models.edit_repo_option.EditRepoOption()  # noqa: E501
        if include_optional :
            return EditRepoOption(
                allow_manual_merge = True, 
                allow_merge_commits = True, 
                allow_rebase = True, 
                allow_rebase_explicit = True, 
                allow_rebase_update = True, 
                allow_squash_merge = True, 
                archived = True, 
                autodetect_manual_merge = True, 
                default_allow_maintainer_edit = True, 
                default_branch = '', 
                default_delete_branch_after_merge = True, 
                default_merge_style = '', 
                description = '', 
                enable_prune = True, 
                external_tracker = py_gitea_opensuse_org.models.external_tracker.ExternalTracker(
                    external_tracker_format = '', 
                    external_tracker_regexp_pattern = '', 
                    external_tracker_style = '', 
                    external_tracker_url = '', ), 
                external_wiki = py_gitea_opensuse_org.models.external_wiki.ExternalWiki(
                    external_wiki_url = '', ), 
                has_issues = True, 
                has_projects = True, 
                has_pull_requests = True, 
                has_wiki = True, 
                ignore_whitespace_conflicts = True, 
                internal_tracker = py_gitea_opensuse_org.models.internal_tracker.InternalTracker(
                    allow_only_contributors_to_track_time = True, 
                    enable_issue_dependencies = True, 
                    enable_time_tracker = True, ), 
                mirror_interval = '', 
                name = '', 
                private = True, 
                template = True, 
                website = ''
            )
        else :
            return EditRepoOption(
        )
        """

    def testEditRepoOption(self):
        """Test EditRepoOption"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.action_workflow_response import ActionWorkflowResponse

class TestActionWorkflowResponse(unittest.TestCase):
    """ActionWorkflowResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionWorkflowResponse:
        """Test ActionWorkflowResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionWorkflowResponse`
        """
        model = ActionWorkflowResponse()
        if include_optional:
            return ActionWorkflowResponse(
                total_count = 56,
                workflows = [
                    py_gitea_opensuse_org.models.action_workflow.ActionWorkflow(
                        badge_url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        deleted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        html_url = '', 
                        id = '', 
                        name = '', 
                        path = '', 
                        state = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        url = '', )
                    ]
            )
        else:
            return ActionWorkflowResponse(
        )
        """

    def testActionWorkflowResponse(self):
        """Test ActionWorkflowResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.external_tracker import ExternalTracker
from py_gitea_opensuse_org.models.external_wiki import ExternalWiki
from py_gitea_opensuse_org.models.internal_tracker import InternalTracker
from typing import Optional, Set
from typing_extensions import Self

class EditRepoOption(BaseModel):
    """
    EditRepoOption options when editing a repository's properties
    """ # noqa: E501
    allow_fast_forward_only_merge: Optional[StrictBool] = Field(default=None, description="either `true` to allow fast-forward-only merging pull requests, or `false` to prevent fast-forward-only merging.")
    allow_manual_merge: Optional[StrictBool] = Field(default=None, description="either `true` to allow mark pr as merged manually, or `false` to prevent it.")
    allow_merge_commits: Optional[StrictBool] = Field(default=None, description="either `true` to allow merging pull requests with a merge commit, or `false` to prevent merging pull requests with merge commits.")
    allow_rebase: Optional[StrictBool] = Field(default=None, description="either `true` to allow rebase-merging pull requests, or `false` to prevent rebase-merging.")
    allow_rebase_explicit: Optional[StrictBool] = Field(default=None, description="either `true` to allow rebase with explicit merge commits (--no-ff), or `false` to prevent rebase with explicit merge commits.")
    allow_rebase_update: Optional[StrictBool] = Field(default=None, description="either `true` to allow updating pull request branch by rebase, or `false` to prevent it.")
    allow_squash_merge: Optional[StrictBool] = Field(default=None, description="either `true` to allow squash-merging pull requests, or `false` to prevent squash-merging.")
    archived: Optional[StrictBool] = Field(default=None, description="set to `true` to archive this repository.")
    autodetect_manual_merge: Optional[StrictBool] = Field(default=None, description="either `true` to enable AutodetectManualMerge, or `false` to prevent it. Note: In some special cases, misjudgments can occur.")
    default_allow_maintainer_edit: Optional[StrictBool] = Field(default=None, description="set to `true` to allow edits from maintainers by default")
    default_branch: Optional[StrictStr] = Field(default=None, description="sets the default branch for this repository.")
    default_delete_branch_after_merge: Optional[StrictBool] = Field(default=None, description="set to `true` to delete pr branch after merge by default")
    default_merge_style: Optional[StrictStr] = Field(default=None, description="set to a merge style to be used by this repository: \"merge\", \"rebase\", \"rebase-merge\", \"squash\", or \"fast-forward-only\".")
    description: Optional[StrictStr] = Field(default=None, description="a short description of the repository.")
    enable_prune: Optional[StrictBool] = Field(default=None, description="enable prune - remove obsolete remote-tracking references when mirroring")
    external_tracker: Optional[ExternalTracker] = None
    external_wiki: Optional[ExternalWiki] = None
    has_actions: Optional[StrictBool] = Field(default=None, description="either `true` to enable actions unit, or `false` to disable them.")
    has_issues: Optional[StrictBool] = Field(default=None, description="either `true` to enable issues for this repository or `false` to disable them.")
    has_packages: Optional[StrictBool] = Field(default=None, description="either `true` to enable packages unit, or `false` to disable them.")
    has_projects: Optional[StrictBool] = Field(default=None, description="either `true` to enable project unit, or `false` to disable them.")
    has_pull_requests: Optional[StrictBool] = Field(default=None, description="either `true` to allow pull requests, or `false` to prevent pull request.")
    has_releases: Optional[StrictBool] = Field(default=None, description="either `true` to enable releases unit, or `false` to disable them.")
    has_wiki: Optional[StrictBool] = Field(default=None, description="either `true` to enable the wiki for this repository or `false` to disable it.")
    ignore_whitespace_conflicts: Optional[StrictBool] = Field(default=None, description="either `true` to ignore whitespace for conflicts, or `false` to not ignore whitespace.")
    internal_tracker: Optional[InternalTracker] = None
    mirror_interval: Optional[StrictStr] = Field(default=None, description="set to a string like `8h30m0s` to set the mirror interval time")
    name: Optional[StrictStr] = Field(default=None, description="name of the repository")
    private: Optional[StrictBool] = Field(default=None, description="either `true` to make the repository private or `false` to make it public. Note: you will get a 422 error if the organization restricts changing repository visibility to organization owners and a non-owner tries to change the value of private.")
    projects_mode: Optional[StrictStr] = Field(default=None, description="`repo` to only allow repo-level projects, `owner` to only allow owner projects, `all` to allow both.")
    template: Optional[StrictBool] = Field(default=None, description="either `true` to make this repository a template or `false` to make it a normal repository")
    website: Optional[StrictStr] = Field(default=None, description="a URL with more information about the repository.")
    __properties: ClassVar[List[str]] = ["allow_fast_forward_only_merge", "allow_manual_merge", "allow_merge_commits", "allow_rebase", "allow_rebase_explicit", "allow_rebase_update", "allow_squash_merge", "archived", "autodetect_manual_merge", "default_allow_maintainer_edit", "default_branch", "default_delete_branch_after_merge", "default_merge_style", "description", "enable_prune", "external_tracker", "external_wiki", "has_actions", "has_issues", "has_packages", "has_projects", "has_pull_requests", "has_releases", "has_wiki", "ignore_whitespace_conflicts", "internal_tracker", "mirror_interval", "name", "private", "projects_mode", "template", "website"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EditRepoOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of external_tracker
        if self.external_tracker:
            _dict['external_tracker'] = self.external_tracker.to_dict()
        # override the default output from pydantic by calling `to_dict()` of external_wiki
        if self.external_wiki:
            _dict['external_wiki'] = self.external_wiki.to_dict()
        # override the default output from pydantic by calling `to_dict()` of internal_tracker
        if self.internal_tracker:
            _dict['internal_tracker'] = self.internal_tracker.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EditRepoOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allow_fast_forward_only_merge": obj.get("allow_fast_forward_only_merge"),
            "allow_manual_merge": obj.get("allow_manual_merge"),
            "allow_merge_commits": obj.get("allow_merge_commits"),
            "allow_rebase": obj.get("allow_rebase"),
            "allow_rebase_explicit": obj.get("allow_rebase_explicit"),
            "allow_rebase_update": obj.get("allow_rebase_update"),
            "allow_squash_merge": obj.get("allow_squash_merge"),
            "archived": obj.get("archived"),
            "autodetect_manual_merge": obj.get("autodetect_manual_merge"),
            "default_allow_maintainer_edit": obj.get("default_allow_maintainer_edit"),
            "default_branch": obj.get("default_branch"),
            "default_delete_branch_after_merge": obj.get("default_delete_branch_after_merge"),
            "default_merge_style": obj.get("default_merge_style"),
            "description": obj.get("description"),
            "enable_prune": obj.get("enable_prune"),
            "external_tracker": ExternalTracker.from_dict(obj["external_tracker"]) if obj.get("external_tracker") is not None else None,
            "external_wiki": ExternalWiki.from_dict(obj["external_wiki"]) if obj.get("external_wiki") is not None else None,
            "has_actions": obj.get("has_actions"),
            "has_issues": obj.get("has_issues"),
            "has_packages": obj.get("has_packages"),
            "has_projects": obj.get("has_projects"),
            "has_pull_requests": obj.get("has_pull_requests"),
            "has_releases": obj.get("has_releases"),
            "has_wiki": obj.get("has_wiki"),
            "ignore_whitespace_conflicts": obj.get("ignore_whitespace_conflicts"),
            "internal_tracker": InternalTracker.from_dict(obj["internal_tracker"]) if obj.get("internal_tracker") is not None else None,
            "mirror_interval": obj.get("mirror_interval"),
            "name": obj.get("name"),
            "private": obj.get("private"),
            "projects_mode": obj.get("projects_mode"),
            "template": obj.get("template"),
            "website": obj.get("website")
        })
        return _obj





# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.gpg_key import GPGKey  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestGPGKey(unittest.TestCase):
    """GPGKey unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GPGKey
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GPGKey`
        """
        model = py_gitea_opensuse_org.models.gpg_key.GPGKey()  # noqa: E501
        if include_optional :
            return GPGKey(
                can_certify = True, 
                can_encrypt_comms = True, 
                can_encrypt_storage = True, 
                can_sign = True, 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                emails = [
                    py_gitea_opensuse_org.models.gpg_key_email.GPGKeyEmail(
                        email = '', 
                        verified = True, )
                    ], 
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                id = 56, 
                key_id = '', 
                primary_key_id = '', 
                public_key = '', 
                subkeys = [
                    py_gitea_opensuse_org.models.gpg_key.GPGKey(
                        can_certify = True, 
                        can_encrypt_comms = True, 
                        can_encrypt_storage = True, 
                        can_sign = True, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        emails = [
                            py_gitea_opensuse_org.models.gpg_key_email.GPGKeyEmail(
                                email = '', 
                                verified = True, )
                            ], 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = 56, 
                        key_id = '', 
                        primary_key_id = '', 
                        public_key = '', 
                        subkeys = [
                            py_gitea_opensuse_org.models.gpg_key.GPGKey(
                                can_certify = True, 
                                can_encrypt_comms = True, 
                                can_encrypt_storage = True, 
                                can_sign = True, 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = 56, 
                                key_id = '', 
                                primary_key_id = '', 
                                public_key = '', 
                                verified = True, )
                            ], 
                        verified = True, )
                    ], 
                verified = True
            )
        else :
            return GPGKey(
        )
        """

    def testGPGKey(self):
        """Test GPGKey"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_gitea_opensuse_org.models.action_artifacts_response import ActionArtifactsResponse

class TestActionArtifactsResponse(unittest.TestCase):
    """ActionArtifactsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionArtifactsResponse:
        """Test ActionArtifactsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionArtifactsResponse`
        """
        model = ActionArtifactsResponse()
        if include_optional:
            return ActionArtifactsResponse(
                artifacts = [
                    py_gitea_opensuse_org.models.action_artifact.ActionArtifact(
                        archive_download_url = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expired = True, 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = 56, 
                        name = '', 
                        size_in_bytes = 56, 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        url = '', 
                        workflow_run = py_gitea_opensuse_org.models.action_workflow_run.ActionWorkflowRun(
                            head_sha = '', 
                            id = 56, 
                            repository_id = 56, ), )
                    ],
                total_count = 56
            )
        else:
            return ActionArtifactsResponse(
        )
        """

    def testActionArtifactsResponse(self):
        """Test ActionArtifactsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.user import User  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestUser(unittest.TestCase):
    """User unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test User
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `User`
        """
        model = py_gitea_opensuse_org.models.user.User()  # noqa: E501
        if include_optional :
            return User(
                active = True, 
                avatar_url = '', 
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                description = '', 
                email = '', 
                followers_count = 56, 
                following_count = 56, 
                full_name = '', 
                id = 56, 
                is_admin = True, 
                language = '', 
                last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                location = '', 
                login = '', 
                login_name = 'empty', 
                prohibit_login = True, 
                restricted = True, 
                starred_repos_count = 56, 
                visibility = '', 
                website = ''
            )
        else :
            return User(
        )
        """

    def testUser(self):
        """Test User"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class BranchProtection(BaseModel):
    """
    BranchProtection represents a branch protection for a repository
    """ # noqa: E501
    approvals_whitelist_teams: Optional[List[StrictStr]] = None
    approvals_whitelist_username: Optional[List[StrictStr]] = None
    block_admin_merge_override: Optional[StrictBool] = None
    block_on_official_review_requests: Optional[StrictBool] = None
    block_on_outdated_branch: Optional[StrictBool] = None
    block_on_rejected_reviews: Optional[StrictBool] = None
    branch_name: Optional[StrictStr] = Field(default=None, description="Deprecated: true")
    created_at: Optional[datetime] = None
    dismiss_stale_approvals: Optional[StrictBool] = None
    enable_approvals_whitelist: Optional[StrictBool] = None
    enable_force_push: Optional[StrictBool] = None
    enable_force_push_allowlist: Optional[StrictBool] = None
    enable_merge_whitelist: Optional[StrictBool] = None
    enable_push: Optional[StrictBool] = None
    enable_push_whitelist: Optional[StrictBool] = None
    enable_status_check: Optional[StrictBool] = None
    force_push_allowlist_deploy_keys: Optional[StrictBool] = None
    force_push_allowlist_teams: Optional[List[StrictStr]] = None
    force_push_allowlist_usernames: Optional[List[StrictStr]] = None
    ignore_stale_approvals: Optional[StrictBool] = None
    merge_whitelist_teams: Optional[List[StrictStr]] = None
    merge_whitelist_usernames: Optional[List[StrictStr]] = None
    priority: Optional[StrictInt] = None
    protected_file_patterns: Optional[StrictStr] = None
    push_whitelist_deploy_keys: Optional[StrictBool] = None
    push_whitelist_teams: Optional[List[StrictStr]] = None
    push_whitelist_usernames: Optional[List[StrictStr]] = None
    require_signed_commits: Optional[StrictBool] = None
    required_approvals: Optional[StrictInt] = None
    rule_name: Optional[StrictStr] = None
    status_check_contexts: Optional[List[StrictStr]] = None
    unprotected_file_patterns: Optional[StrictStr] = None
    updated_at: Optional[datetime] = None
    __properties: ClassVar[List[str]] = ["approvals_whitelist_teams", "approvals_whitelist_username", "block_admin_merge_override", "block_on_official_review_requests", "block_on_outdated_branch", "block_on_rejected_reviews", "branch_name", "created_at", "dismiss_stale_approvals", "enable_approvals_whitelist", "enable_force_push", "enable_force_push_allowlist", "enable_merge_whitelist", "enable_push", "enable_push_whitelist", "enable_status_check", "force_push_allowlist_deploy_keys", "force_push_allowlist_teams", "force_push_allowlist_usernames", "ignore_stale_approvals", "merge_whitelist_teams", "merge_whitelist_usernames", "priority", "protected_file_patterns", "push_whitelist_deploy_keys", "push_whitelist_teams", "push_whitelist_usernames", "require_signed_commits", "required_approvals", "rule_name", "status_check_contexts", "unprotected_file_patterns", "updated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BranchProtection from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BranchProtection from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "approvals_whitelist_teams": obj.get("approvals_whitelist_teams"),
            "approvals_whitelist_username": obj.get("approvals_whitelist_username"),
            "block_admin_merge_override": obj.get("block_admin_merge_override"),
            "block_on_official_review_requests": obj.get("block_on_official_review_requests"),
            "block_on_outdated_branch": obj.get("block_on_outdated_branch"),
            "block_on_rejected_reviews": obj.get("block_on_rejected_reviews"),
            "branch_name": obj.get("branch_name"),
            "created_at": obj.get("created_at"),
            "dismiss_stale_approvals": obj.get("dismiss_stale_approvals"),
            "enable_approvals_whitelist": obj.get("enable_approvals_whitelist"),
            "enable_force_push": obj.get("enable_force_push"),
            "enable_force_push_allowlist": obj.get("enable_force_push_allowlist"),
            "enable_merge_whitelist": obj.get("enable_merge_whitelist"),
            "enable_push": obj.get("enable_push"),
            "enable_push_whitelist": obj.get("enable_push_whitelist"),
            "enable_status_check": obj.get("enable_status_check"),
            "force_push_allowlist_deploy_keys": obj.get("force_push_allowlist_deploy_keys"),
            "force_push_allowlist_teams": obj.get("force_push_allowlist_teams"),
            "force_push_allowlist_usernames": obj.get("force_push_allowlist_usernames"),
            "ignore_stale_approvals": obj.get("ignore_stale_approvals"),
            "merge_whitelist_teams": obj.get("merge_whitelist_teams"),
            "merge_whitelist_usernames": obj.get("merge_whitelist_usernames"),
            "priority": obj.get("priority"),
            "protected_file_patterns": obj.get("protected_file_patterns"),
            "push_whitelist_deploy_keys": obj.get("push_whitelist_deploy_keys"),
            "push_whitelist_teams": obj.get("push_whitelist_teams"),
            "push_whitelist_usernames": obj.get("push_whitelist_usernames"),
            "require_signed_commits": obj.get("require_signed_commits"),
            "required_approvals": obj.get("required_approvals"),
            "rule_name": obj.get("rule_name"),
            "status_check_contexts": obj.get("status_check_contexts"),
            "unprotected_file_patterns": obj.get("unprotected_file_patterns"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.21.0-rc1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from py_gitea_opensuse_org.models.change_file_operation import ChangeFileOperation


class TestChangeFileOperation(unittest.TestCase):
    """ChangeFileOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChangeFileOperation:
        """Test ChangeFileOperation
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ChangeFileOperation`
        """
        model = ChangeFileOperation()
        if include_optional:
            return ChangeFileOperation(
                content = '',
                from_path = '',
                operation = 'create',
                path = '',
                sha = ''
            )
        else:
            return ChangeFileOperation(
                operation = 'create',
                path = '',
        )
        """

    def testChangeFileOperation(self):
        """Test ChangeFileOperation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import py_gitea_opensuse_org
from py_gitea_opensuse_org.models.timeline_comment import TimelineComment  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestTimelineComment(unittest.TestCase):
    """TimelineComment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TimelineComment
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `TimelineComment`
        """
        model = py_gitea_opensuse_org.models.timeline_comment.TimelineComment()  # noqa: E501
        if include_optional :
            return TimelineComment(
                assignee = py_gitea_opensuse_org.models.user.User(
                    active = True, 
                    avatar_url = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    email = '', 
                    followers_count = 56, 
                    following_count = 56, 
                    full_name = '', 
                    id = 56, 
                    is_admin = True, 
                    language = '', 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    location = '', 
                    login = '', 
                    login_name = 'empty', 
                    prohibit_login = True, 
                    restricted = True, 
                    starred_repos_count = 56, 
                    visibility = '', 
                    website = '', ), 
                assignee_team = py_gitea_opensuse_org.models.team.Team(
                    can_create_org_repo = True, 
                    description = '', 
                    id = 56, 
                    includes_all_repositories = True, 
                    name = '', 
                    organization = py_gitea_opensuse_org.models.organization.Organization(
                        avatar_url = '', 
                        description = '', 
                        full_name = '', 
                        id = 56, 
                        location = '', 
                        name = '', 
                        repo_admin_change_team_access = True, 
                        username = '', 
                        visibility = '', 
                        website = '', ), 
                    permission = 'none', 
                    units = [repo.code, repo.issues, repo.ext_issues, repo.wiki, repo.pulls, repo.releases, repo.projects, repo.ext_wiki], 
                    units_map = {"repo.code":"read","repo.ext_issues":"none","repo.ext_wiki":"none","repo.issues":"write","repo.projects":"none","repo.pulls":"owner","repo.releases":"none","repo.wiki":"admin"}, ), 
                body = '', 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                dependent_issue = py_gitea_opensuse_org.models.issue.Issue(
                    assets = [
                        py_gitea_opensuse_org.models.attachment.Attachment(
                            browser_download_url = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            download_count = 56, 
                            id = 56, 
                            name = '', 
                            size = 56, 
                            uuid = '', )
                        ], 
                    assignee = py_gitea_opensuse_org.models.user.User(
                        active = True, 
                        avatar_url = '', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        email = '', 
                        followers_count = 56, 
                        following_count = 56, 
                        full_name = '', 
                        id = 56, 
                        is_admin = True, 
                        language = '', 
                        last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        location = '', 
                        login = '', 
                        login_name = 'empty', 
                        prohibit_login = True, 
                        restricted = True, 
                        starred_repos_count = 56, 
                        visibility = '', 
                        website = '', ), 
                    assignees = [
                        py_gitea_opensuse_org.models.user.User(
                            active = True, 
                            avatar_url = '', 
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            email = '', 
                            followers_count = 56, 
                            following_count = 56, 
                            full_name = '', 
                            id = 56, 
                            is_admin = True, 
                            language = '', 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            location = '', 
                            login = '', 
                            login_name = 'empty', 
                            prohibit_login = True, 
                            restricted = True, 
                            starred_repos_count = 56, 
                            visibility = '', 
                            website = '', )
                        ], 
                    body = '', 
                    closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    comments = 56, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    due_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    html_url = '', 
                    id = 56, 
                    is_locked = True, 
                    labels = [
                        py_gitea_opensuse_org.models.label.Label(
                            color = '00aabb', 
                            description = '', 
                            exclusive = False, 
                            id = 56, 
                            name = '', 
                            url = '', )
                        ], 
                    milestone = py_gitea_opensuse_org.models.milestone.Milestone(
                        closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        closed_issues = 56, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        due_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = 56, 
                        open_issues = 56, 
                        state = '', 
                        title = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    number = 56, 
                    original_author = '', 
                    original_author_id = 56, 
                    pull_request = py_gitea_opensuse_org.models.pull_request_meta.PullRequestMeta(
                        merged = True, 
                        merged_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    ref = '', 
                    repository = py_gitea_opensuse_org.models.repository_meta.RepositoryMeta(
                        full_name = '', 
                        id = 56, 
                        name = '', 
                        owner = '', ), 
                    state = '', 
                    title = '', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    url = '', 
                    user = , ), 
                html_url = '', 
                id = 56, 
                issue_url = '', 
                label = py_gitea_opensuse_org.models.label.Label(
                    color = '00aabb', 
                    description = '', 
                    exclusive = False, 
                    id = 56, 
                    name = '', 
                    url = '', ), 
                milestone = py_gitea_opensuse_org.models.milestone.Milestone(
                    closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    closed_issues = 56, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    due_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = 56, 
                    open_issues = 56, 
                    state = '', 
                    title = '', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                new_ref = '', 
                new_title = '', 
                old_milestone = py_gitea_opensuse_org.models.milestone.Milestone(
                    closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    closed_issues = 56, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    due_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = 56, 
                    open_issues = 56, 
                    state = '', 
                    title = '', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                old_project_id = 56, 
                old_ref = '', 
                old_title = '', 
                project_id = 56, 
                pull_request_url = '', 
                ref_action = '', 
                ref_comment = py_gitea_opensuse_org.models.comment.Comment(
                    assets = [
                        py_gitea_opensuse_org.models.attachment.Attachment(
                            browser_download_url = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            download_count = 56, 
                            id = 56, 
                            name = '', 
                            size = 56, 
                            uuid = '', )
                        ], 
                    body = '', 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    html_url = '', 
                    id = 56, 
                    issue_url = '', 
                    original_author = '', 
                    original_author_id = 56, 
                    pull_request_url = '', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    user = py_gitea_opensuse_org.models.user.User(
                        active = True, 
                        avatar_url = '', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        email = '', 
                        followers_count = 56, 
                        following_count = 56, 
                        full_name = '', 
                        id = 56, 
                        is_admin = True, 
                        language = '', 
                        last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        location = '', 
                        login = '', 
                        login_name = 'empty', 
                        prohibit_login = True, 
                        restricted = True, 
                        starred_repos_count = 56, 
                        visibility = '', 
                        website = '', ), ), 
                ref_commit_sha = '', 
                ref_issue = py_gitea_opensuse_org.models.issue.Issue(
                    assets = [
                        py_gitea_opensuse_org.models.attachment.Attachment(
                            browser_download_url = '', 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            download_count = 56, 
                            id = 56, 
                            name = '', 
                            size = 56, 
                            uuid = '', )
                        ], 
                    assignee = py_gitea_opensuse_org.models.user.User(
                        active = True, 
                        avatar_url = '', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        email = '', 
                        followers_count = 56, 
                        following_count = 56, 
                        full_name = '', 
                        id = 56, 
                        is_admin = True, 
                        language = '', 
                        last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        location = '', 
                        login = '', 
                        login_name = 'empty', 
                        prohibit_login = True, 
                        restricted = True, 
                        starred_repos_count = 56, 
                        visibility = '', 
                        website = '', ), 
                    assignees = [
                        py_gitea_opensuse_org.models.user.User(
                            active = True, 
                            avatar_url = '', 
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            email = '', 
                            followers_count = 56, 
                            following_count = 56, 
                            full_name = '', 
                            id = 56, 
                            is_admin = True, 
                            language = '', 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            location = '', 
                            login = '', 
                            login_name = 'empty', 
                            prohibit_login = True, 
                            restricted = True, 
                            starred_repos_count = 56, 
                            visibility = '', 
                            website = '', )
                        ], 
                    body = '', 
                    closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    comments = 56, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    due_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    html_url = '', 
                    id = 56, 
                    is_locked = True, 
                    labels = [
                        py_gitea_opensuse_org.models.label.Label(
                            color = '00aabb', 
                            description = '', 
                            exclusive = False, 
                            id = 56, 
                            name = '', 
                            url = '', )
                        ], 
                    milestone = py_gitea_opensuse_org.models.milestone.Milestone(
                        closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        closed_issues = 56, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        due_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = 56, 
                        open_issues = 56, 
                        state = '', 
                        title = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    number = 56, 
                    original_author = '', 
                    original_author_id = 56, 
                    pull_request = py_gitea_opensuse_org.models.pull_request_meta.PullRequestMeta(
                        merged = True, 
                        merged_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    ref = '', 
                    repository = py_gitea_opensuse_org.models.repository_meta.RepositoryMeta(
                        full_name = '', 
                        id = 56, 
                        name = '', 
                        owner = '', ), 
                    state = '', 
                    title = '', 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    url = '', 
                    user = , ), 
                removed_assignee = True, 
                resolve_doer = py_gitea_opensuse_org.models.user.User(
                    active = True, 
                    avatar_url = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    email = '', 
                    followers_count = 56, 
                    following_count = 56, 
                    full_name = '', 
                    id = 56, 
                    is_admin = True, 
                    language = '', 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    location = '', 
                    login = '', 
                    login_name = 'empty', 
                    prohibit_login = True, 
                    restricted = True, 
                    starred_repos_count = 56, 
                    visibility = '', 
                    website = '', ), 
                review_id = 56, 
                tracked_time = py_gitea_opensuse_org.models.tracked_time.TrackedTime(
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    id = 56, 
                    issue = py_gitea_opensuse_org.models.issue.Issue(
                        assets = [
                            py_gitea_opensuse_org.models.attachment.Attachment(
                                browser_download_url = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                download_count = 56, 
                                id = 56, 
                                name = '', 
                                size = 56, 
                                uuid = '', )
                            ], 
                        assignee = py_gitea_opensuse_org.models.user.User(
                            active = True, 
                            avatar_url = '', 
                            created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            email = '', 
                            followers_count = 56, 
                            following_count = 56, 
                            full_name = '', 
                            id = 56, 
                            is_admin = True, 
                            language = '', 
                            last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            location = '', 
                            login = '', 
                            login_name = 'empty', 
                            prohibit_login = True, 
                            restricted = True, 
                            starred_repos_count = 56, 
                            visibility = '', 
                            website = '', ), 
                        assignees = [
                            py_gitea_opensuse_org.models.user.User(
                                active = True, 
                                avatar_url = '', 
                                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                description = '', 
                                email = '', 
                                followers_count = 56, 
                                following_count = 56, 
                                full_name = '', 
                                id = 56, 
                                is_admin = True, 
                                language = '', 
                                last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                location = '', 
                                login = '', 
                                login_name = 'empty', 
                                prohibit_login = True, 
                                restricted = True, 
                                starred_repos_count = 56, 
                                visibility = '', 
                                website = '', )
                            ], 
                        body = '', 
                        closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        comments = 56, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        due_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        html_url = '', 
                        id = 56, 
                        is_locked = True, 
                        labels = [
                            py_gitea_opensuse_org.models.label.Label(
                                color = '00aabb', 
                                description = '', 
                                exclusive = False, 
                                id = 56, 
                                name = '', 
                                url = '', )
                            ], 
                        milestone = py_gitea_opensuse_org.models.milestone.Milestone(
                            closed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            closed_issues = 56, 
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            description = '', 
                            due_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            id = 56, 
                            open_issues = 56, 
                            state = '', 
                            title = '', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        number = 56, 
                        original_author = '', 
                        original_author_id = 56, 
                        pull_request = py_gitea_opensuse_org.models.pull_request_meta.PullRequestMeta(
                            merged = True, 
                            merged_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        ref = '', 
                        repository = py_gitea_opensuse_org.models.repository_meta.RepositoryMeta(
                            full_name = '', 
                            id = 56, 
                            name = '', 
                            owner = '', ), 
                        state = '', 
                        title = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        url = '', 
                        user = , ), 
                    issue_id = 56, 
                    time = 56, 
                    user_id = 56, 
                    user_name = '', ), 
                type = '', 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                user = py_gitea_opensuse_org.models.user.User(
                    active = True, 
                    avatar_url = '', 
                    created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    email = '', 
                    followers_count = 56, 
                    following_count = 56, 
                    full_name = '', 
                    id = 56, 
                    is_admin = True, 
                    language = '', 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    location = '', 
                    login = '', 
                    login_name = 'empty', 
                    prohibit_login = True, 
                    restricted = True, 
                    starred_repos_count = 56, 
                    visibility = '', 
                    website = '', )
            )
        else :
            return TimelineComment(
        )
        """

    def testTimelineComment(self):
        """Test TimelineComment"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MigrateRepoOptions(BaseModel):
    """
    MigrateRepoOptions options for migrating repository's this is used to interact with api v1
    """ # noqa: E501
    auth_password: Optional[StrictStr] = None
    auth_token: Optional[StrictStr] = None
    auth_username: Optional[StrictStr] = None
    aws_access_key_id: Optional[StrictStr] = None
    aws_secret_access_key: Optional[StrictStr] = None
    clone_addr: StrictStr
    description: Optional[StrictStr] = None
    issues: Optional[StrictBool] = None
    labels: Optional[StrictBool] = None
    lfs: Optional[StrictBool] = None
    lfs_endpoint: Optional[StrictStr] = None
    milestones: Optional[StrictBool] = None
    mirror: Optional[StrictBool] = None
    mirror_interval: Optional[StrictStr] = None
    private: Optional[StrictBool] = None
    pull_requests: Optional[StrictBool] = None
    releases: Optional[StrictBool] = None
    repo_name: StrictStr
    repo_owner: Optional[StrictStr] = Field(default=None, description="Name of User or Organisation who will own Repo after migration")
    service: Optional[StrictStr] = None
    uid: Optional[StrictInt] = Field(default=None, description="deprecated (only for backwards compatibility)")
    wiki: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["auth_password", "auth_token", "auth_username", "aws_access_key_id", "aws_secret_access_key", "clone_addr", "description", "issues", "labels", "lfs", "lfs_endpoint", "milestones", "mirror", "mirror_interval", "private", "pull_requests", "releases", "repo_name", "repo_owner", "service", "uid", "wiki"]

    @field_validator('service')
    def service_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['git', 'github', 'gitea', 'gitlab', 'gogs', 'onedev', 'gitbucket', 'codebase', 'codecommit']):
            raise ValueError("must be one of enum values ('git', 'github', 'gitea', 'gitlab', 'gogs', 'onedev', 'gitbucket', 'codebase', 'codecommit')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MigrateRepoOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MigrateRepoOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "auth_password": obj.get("auth_password"),
            "auth_token": obj.get("auth_token"),
            "auth_username": obj.get("auth_username"),
            "aws_access_key_id": obj.get("aws_access_key_id"),
            "aws_secret_access_key": obj.get("aws_secret_access_key"),
            "clone_addr": obj.get("clone_addr"),
            "description": obj.get("description"),
            "issues": obj.get("issues"),
            "labels": obj.get("labels"),
            "lfs": obj.get("lfs"),
            "lfs_endpoint": obj.get("lfs_endpoint"),
            "milestones": obj.get("milestones"),
            "mirror": obj.get("mirror"),
            "mirror_interval": obj.get("mirror_interval"),
            "private": obj.get("private"),
            "pull_requests": obj.get("pull_requests"),
            "releases": obj.get("releases"),
            "repo_name": obj.get("repo_name"),
            "repo_owner": obj.get("repo_owner"),
            "service": obj.get("service"),
            "uid": obj.get("uid"),
            "wiki": obj.get("wiki")
        })
        return _obj





# flake8: noqa

# import apis into api package
from py_gitea_opensuse_org.api.activitypub_api import ActivitypubApi
from py_gitea_opensuse_org.api.admin_api import AdminApi
from py_gitea_opensuse_org.api.issue_api import IssueApi
from py_gitea_opensuse_org.api.miscellaneous_api import MiscellaneousApi
from py_gitea_opensuse_org.api.notification_api import NotificationApi
from py_gitea_opensuse_org.api.organization_api import OrganizationApi
from py_gitea_opensuse_org.api.package_api import PackageApi
from py_gitea_opensuse_org.api.repository_api import RepositoryApi
from py_gitea_opensuse_org.api.settings_api import SettingsApi
from py_gitea_opensuse_org.api.user_api import UserApi




# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class EditUserOption(BaseModel):
    """
    EditUserOption edit user options
    """ # noqa: E501
    active: Optional[StrictBool] = None
    admin: Optional[StrictBool] = None
    allow_create_organization: Optional[StrictBool] = None
    allow_git_hook: Optional[StrictBool] = None
    allow_import_local: Optional[StrictBool] = None
    description: Optional[StrictStr] = None
    email: Optional[StrictStr] = None
    full_name: Optional[StrictStr] = None
    location: Optional[StrictStr] = None
    login_name: StrictStr
    max_repo_creation: Optional[StrictInt] = None
    must_change_password: Optional[StrictBool] = None
    password: Optional[StrictStr] = None
    prohibit_login: Optional[StrictBool] = None
    restricted: Optional[StrictBool] = None
    source_id: StrictInt
    visibility: Optional[StrictStr] = None
    website: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["active", "admin", "allow_create_organization", "allow_git_hook", "allow_import_local", "description", "email", "full_name", "location", "login_name", "max_repo_creation", "must_change_password", "password", "prohibit_login", "restricted", "source_id", "visibility", "website"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EditUserOption from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EditUserOption from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "active": obj.get("active"),
            "admin": obj.get("admin"),
            "allow_create_organization": obj.get("allow_create_organization"),
            "allow_git_hook": obj.get("allow_git_hook"),
            "allow_import_local": obj.get("allow_import_local"),
            "description": obj.get("description"),
            "email": obj.get("email"),
            "full_name": obj.get("full_name"),
            "location": obj.get("location"),
            "login_name": obj.get("login_name"),
            "max_repo_creation": obj.get("max_repo_creation"),
            "must_change_password": obj.get("must_change_password"),
            "password": obj.get("password"),
            "prohibit_login": obj.get("prohibit_login"),
            "restricted": obj.get("restricted"),
            "source_id": obj.get("source_id"),
            "visibility": obj.get("visibility"),
            "website": obj.get("website")
        })
        return _obj





# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import py_gitea_opensuse_org
from py_gitea_opensuse_org.api.notification_api import NotificationApi  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestNotificationApi(unittest.TestCase):
    """NotificationApi unit test stubs"""

    def setUp(self):
        self.api = (
            py_gitea_opensuse_org.api.notification_api.NotificationApi()
        )  # noqa: E501

    def tearDown(self):
        pass

    def test_notify_get_list(self):
        """Test case for notify_get_list

        List users's notification threads  # noqa: E501
        """
        pass

    def test_notify_get_repo_list(self):
        """Test case for notify_get_repo_list

        List users's notification threads on a specific repo  # noqa: E501
        """
        pass

    def test_notify_get_thread(self):
        """Test case for notify_get_thread

        Get notification thread by ID  # noqa: E501
        """
        pass

    def test_notify_new_available(self):
        """Test case for notify_new_available

        Check if unread notifications exist  # noqa: E501
        """
        pass

    def test_notify_read_list(self):
        """Test case for notify_read_list

        Mark notification threads as read, pinned or unread  # noqa: E501
        """
        pass

    def test_notify_read_repo_list(self):
        """Test case for notify_read_repo_list

        Mark notification threads as read, pinned or unread on a specific repo  # noqa: E501
        """
        pass

    def test_notify_read_thread(self):
        """Test case for notify_read_thread

        Mark notification thread as read by ID  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from py_gitea_opensuse_org.models.comment import Comment
from py_gitea_opensuse_org.models.repository import Repository
from py_gitea_opensuse_org.models.user import User
from typing import Optional, Set
from typing_extensions import Self

class Activity(BaseModel):
    """
    Activity
    """ # noqa: E501
    act_user: Optional[User] = None
    act_user_id: Optional[StrictInt] = None
    comment: Optional[Comment] = None
    comment_id: Optional[StrictInt] = None
    content: Optional[StrictStr] = None
    created: Optional[datetime] = None
    id: Optional[StrictInt] = None
    is_private: Optional[StrictBool] = None
    op_type: Optional[StrictStr] = Field(default=None, description="the type of action")
    ref_name: Optional[StrictStr] = None
    repo: Optional[Repository] = None
    repo_id: Optional[StrictInt] = None
    user_id: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["act_user", "act_user_id", "comment", "comment_id", "content", "created", "id", "is_private", "op_type", "ref_name", "repo", "repo_id", "user_id"]

    @field_validator('op_type')
    def op_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['create_repo', 'rename_repo', 'star_repo', 'watch_repo', 'commit_repo', 'create_issue', 'create_pull_request', 'transfer_repo', 'push_tag', 'comment_issue', 'merge_pull_request', 'close_issue', 'reopen_issue', 'close_pull_request', 'reopen_pull_request', 'delete_tag', 'delete_branch', 'mirror_sync_push', 'mirror_sync_create', 'mirror_sync_delete', 'approve_pull_request', 'reject_pull_request', 'comment_pull', 'publish_release', 'pull_review_dismissed', 'pull_request_ready_for_review', 'auto_merge_pull_request']):
            raise ValueError("must be one of enum values ('create_repo', 'rename_repo', 'star_repo', 'watch_repo', 'commit_repo', 'create_issue', 'create_pull_request', 'transfer_repo', 'push_tag', 'comment_issue', 'merge_pull_request', 'close_issue', 'reopen_issue', 'close_pull_request', 'reopen_pull_request', 'delete_tag', 'delete_branch', 'mirror_sync_push', 'mirror_sync_create', 'mirror_sync_delete', 'approve_pull_request', 'reject_pull_request', 'comment_pull', 'publish_release', 'pull_review_dismissed', 'pull_request_ready_for_review', 'auto_merge_pull_request')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Activity from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of act_user
        if self.act_user:
            _dict['act_user'] = self.act_user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of comment
        if self.comment:
            _dict['comment'] = self.comment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of repo
        if self.repo:
            _dict['repo'] = self.repo.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Activity from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "act_user": User.from_dict(obj["act_user"]) if obj.get("act_user") is not None else None,
            "act_user_id": obj.get("act_user_id"),
            "comment": Comment.from_dict(obj["comment"]) if obj.get("comment") is not None else None,
            "comment_id": obj.get("comment_id"),
            "content": obj.get("content"),
            "created": obj.get("created"),
            "id": obj.get("id"),
            "is_private": obj.get("is_private"),
            "op_type": obj.get("op_type"),
            "ref_name": obj.get("ref_name"),
            "repo": Repository.from_dict(obj["repo"]) if obj.get("repo") is not None else None,
            "repo_id": obj.get("repo_id"),
            "user_id": obj.get("user_id")
        })
        return _obj





# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import py_gitea_opensuse_org
from py_gitea_opensuse_org.api.admin_api import AdminApi  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self):
        self.api = py_gitea_opensuse_org.api.admin_api.AdminApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_admin_adopt_repository(self):
        """Test case for admin_adopt_repository

        Adopt unadopted files as a repository  # noqa: E501
        """
        pass

    def test_admin_create_hook(self):
        """Test case for admin_create_hook

        Create a hook  # noqa: E501
        """
        pass

    def test_admin_create_org(self):
        """Test case for admin_create_org

        Create an organization  # noqa: E501
        """
        pass

    def test_admin_create_public_key(self):
        """Test case for admin_create_public_key

        Add a public key on behalf of a user  # noqa: E501
        """
        pass

    def test_admin_create_repo(self):
        """Test case for admin_create_repo

        Create a repository on behalf of a user  # noqa: E501
        """
        pass

    def test_admin_create_user(self):
        """Test case for admin_create_user

        Create a user  # noqa: E501
        """
        pass

    def test_admin_cron_list(self):
        """Test case for admin_cron_list

        List cron tasks  # noqa: E501
        """
        pass

    def test_admin_cron_run(self):
        """Test case for admin_cron_run

        Run cron task  # noqa: E501
        """
        pass

    def test_admin_delete_hook(self):
        """Test case for admin_delete_hook

        Delete a hook  # noqa: E501
        """
        pass

    def test_admin_delete_unadopted_repository(self):
        """Test case for admin_delete_unadopted_repository

        Delete unadopted files  # noqa: E501
        """
        pass

    def test_admin_delete_user(self):
        """Test case for admin_delete_user

        Delete a user  # noqa: E501
        """
        pass

    def test_admin_delete_user_public_key(self):
        """Test case for admin_delete_user_public_key

        Delete a user's public key  # noqa: E501
        """
        pass

    def test_admin_edit_hook(self):
        """Test case for admin_edit_hook

        Update a hook  # noqa: E501
        """
        pass

    def test_admin_edit_user(self):
        """Test case for admin_edit_user

        Edit an existing user  # noqa: E501
        """
        pass

    def test_admin_get_all_orgs(self):
        """Test case for admin_get_all_orgs

        List all organizations  # noqa: E501
        """
        pass

    def test_admin_get_all_users(self):
        """Test case for admin_get_all_users

        List all users  # noqa: E501
        """
        pass

    def test_admin_get_hook(self):
        """Test case for admin_get_hook

        Get a hook  # noqa: E501
        """
        pass

    def test_admin_list_hooks(self):
        """Test case for admin_list_hooks

        List system's webhooks  # noqa: E501
        """
        pass

    def test_admin_unadopted_list(self):
        """Test case for admin_unadopted_list

        List unadopted repositories  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import py_gitea_opensuse_org
from py_gitea_opensuse_org.api.organization_api import OrganizationApi  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestOrganizationApi(unittest.TestCase):
    """OrganizationApi unit test stubs"""

    def setUp(self):
        self.api = (
            py_gitea_opensuse_org.api.organization_api.OrganizationApi()
        )  # noqa: E501

    def tearDown(self):
        pass

    def test_create_org_repo(self):
        """Test case for create_org_repo

        Create a repository in an organization  # noqa: E501
        """
        pass

    def test_create_org_repo_deprecated(self):
        """Test case for create_org_repo_deprecated

        Create a repository in an organization  # noqa: E501
        """
        pass

    def test_org_add_team_member(self):
        """Test case for org_add_team_member

        Add a team member  # noqa: E501
        """
        pass

    def test_org_add_team_repository(self):
        """Test case for org_add_team_repository

        Add a repository to a team  # noqa: E501
        """
        pass

    def test_org_conceal_member(self):
        """Test case for org_conceal_member

        Conceal a user's membership  # noqa: E501
        """
        pass

    def test_org_create(self):
        """Test case for org_create

        Create an organization  # noqa: E501
        """
        pass

    def test_org_create_hook(self):
        """Test case for org_create_hook

        Create a hook  # noqa: E501
        """
        pass

    def test_org_create_label(self):
        """Test case for org_create_label

        Create a label for an organization  # noqa: E501
        """
        pass

    def test_org_create_team(self):
        """Test case for org_create_team

        Create a team  # noqa: E501
        """
        pass

    def test_org_delete(self):
        """Test case for org_delete

        Delete an organization  # noqa: E501
        """
        pass

    def test_org_delete_hook(self):
        """Test case for org_delete_hook

        Delete a hook  # noqa: E501
        """
        pass

    def test_org_delete_label(self):
        """Test case for org_delete_label

        Delete a label  # noqa: E501
        """
        pass

    def test_org_delete_member(self):
        """Test case for org_delete_member

        Remove a member from an organization  # noqa: E501
        """
        pass

    def test_org_delete_team(self):
        """Test case for org_delete_team

        Delete a team  # noqa: E501
        """
        pass

    def test_org_edit(self):
        """Test case for org_edit

        Edit an organization  # noqa: E501
        """
        pass

    def test_org_edit_hook(self):
        """Test case for org_edit_hook

        Update a hook  # noqa: E501
        """
        pass

    def test_org_edit_label(self):
        """Test case for org_edit_label

        Update a label  # noqa: E501
        """
        pass

    def test_org_edit_team(self):
        """Test case for org_edit_team

        Edit a team  # noqa: E501
        """
        pass

    def test_org_get(self):
        """Test case for org_get

        Get an organization  # noqa: E501
        """
        pass

    def test_org_get_all(self):
        """Test case for org_get_all

        Get list of organizations  # noqa: E501
        """
        pass

    def test_org_get_hook(self):
        """Test case for org_get_hook

        Get a hook  # noqa: E501
        """
        pass

    def test_org_get_label(self):
        """Test case for org_get_label

        Get a single label  # noqa: E501
        """
        pass

    def test_org_get_team(self):
        """Test case for org_get_team

        Get a team  # noqa: E501
        """
        pass

    def test_org_get_user_permissions(self):
        """Test case for org_get_user_permissions

        Get user permissions in organization  # noqa: E501
        """
        pass

    def test_org_is_member(self):
        """Test case for org_is_member

        Check if a user is a member of an organization  # noqa: E501
        """
        pass

    def test_org_is_public_member(self):
        """Test case for org_is_public_member

        Check if a user is a public member of an organization  # noqa: E501
        """
        pass

    def test_org_list_current_user_orgs(self):
        """Test case for org_list_current_user_orgs

        List the current user's organizations  # noqa: E501
        """
        pass

    def test_org_list_hooks(self):
        """Test case for org_list_hooks

        List an organization's webhooks  # noqa: E501
        """
        pass

    def test_org_list_labels(self):
        """Test case for org_list_labels

        List an organization's labels  # noqa: E501
        """
        pass

    def test_org_list_members(self):
        """Test case for org_list_members

        List an organization's members  # noqa: E501
        """
        pass

    def test_org_list_public_members(self):
        """Test case for org_list_public_members

        List an organization's public members  # noqa: E501
        """
        pass

    def test_org_list_repos(self):
        """Test case for org_list_repos

        List an organization's repos  # noqa: E501
        """
        pass

    def test_org_list_team_member(self):
        """Test case for org_list_team_member

        List a particular member of team  # noqa: E501
        """
        pass

    def test_org_list_team_members(self):
        """Test case for org_list_team_members

        List a team's members  # noqa: E501
        """
        pass

    def test_org_list_team_repo(self):
        """Test case for org_list_team_repo

        List a particular repo of team  # noqa: E501
        """
        pass

    def test_org_list_team_repos(self):
        """Test case for org_list_team_repos

        List a team's repos  # noqa: E501
        """
        pass

    def test_org_list_teams(self):
        """Test case for org_list_teams

        List an organization's teams  # noqa: E501
        """
        pass

    def test_org_list_user_orgs(self):
        """Test case for org_list_user_orgs

        List a user's organizations  # noqa: E501
        """
        pass

    def test_org_publicize_member(self):
        """Test case for org_publicize_member

        Publicize a user's membership  # noqa: E501
        """
        pass

    def test_org_remove_team_member(self):
        """Test case for org_remove_team_member

        Remove a team member  # noqa: E501
        """
        pass

    def test_org_remove_team_repository(self):
        """Test case for org_remove_team_repository

        Remove a repository from a team  # noqa: E501
        """
        pass

    def test_team_search(self):
        """Test case for team_search

        Search for teams within an organization  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class User(BaseModel):
    """
    User represents a user
    """ # noqa: E501
    active: Optional[StrictBool] = Field(default=None, description="Is user active")
    avatar_url: Optional[StrictStr] = Field(default=None, description="URL to the user's avatar")
    created: Optional[datetime] = None
    description: Optional[StrictStr] = Field(default=None, description="the user's description")
    email: Optional[StrictStr] = None
    followers_count: Optional[StrictInt] = Field(default=None, description="user counts")
    following_count: Optional[StrictInt] = None
    full_name: Optional[StrictStr] = Field(default=None, description="the user's full name")
    html_url: Optional[StrictStr] = Field(default=None, description="URL to the user's gitea page")
    id: Optional[StrictInt] = Field(default=None, description="the user's id")
    is_admin: Optional[StrictBool] = Field(default=None, description="Is the user an administrator")
    language: Optional[StrictStr] = Field(default=None, description="User locale")
    last_login: Optional[datetime] = None
    location: Optional[StrictStr] = Field(default=None, description="the user's location")
    login: Optional[StrictStr] = Field(default=None, description="the user's username")
    login_name: Optional[StrictStr] = Field(default='empty', description="the user's authentication sign-in name.")
    prohibit_login: Optional[StrictBool] = Field(default=None, description="Is user login prohibited")
    restricted: Optional[StrictBool] = Field(default=None, description="Is user restricted")
    source_id: Optional[StrictInt] = Field(default=None, description="The ID of the user's Authentication Source")
    starred_repos_count: Optional[StrictInt] = None
    visibility: Optional[StrictStr] = Field(default=None, description="User visibility level option: public, limited, private")
    website: Optional[StrictStr] = Field(default=None, description="the user's website")
    __properties: ClassVar[List[str]] = ["active", "avatar_url", "created", "description", "email", "followers_count", "following_count", "full_name", "html_url", "id", "is_admin", "language", "last_login", "location", "login", "login_name", "prohibit_login", "restricted", "source_id", "starred_repos_count", "visibility", "website"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of User from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of User from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "active": obj.get("active"),
            "avatar_url": obj.get("avatar_url"),
            "created": obj.get("created"),
            "description": obj.get("description"),
            "email": obj.get("email"),
            "followers_count": obj.get("followers_count"),
            "following_count": obj.get("following_count"),
            "full_name": obj.get("full_name"),
            "html_url": obj.get("html_url"),
            "id": obj.get("id"),
            "is_admin": obj.get("is_admin"),
            "language": obj.get("language"),
            "last_login": obj.get("last_login"),
            "location": obj.get("location"),
            "login": obj.get("login"),
            "login_name": obj.get("login_name") if obj.get("login_name") is not None else 'empty',
            "prohibit_login": obj.get("prohibit_login"),
            "restricted": obj.get("restricted"),
            "source_id": obj.get("source_id"),
            "starred_repos_count": obj.get("starred_repos_count"),
            "visibility": obj.get("visibility"),
            "website": obj.get("website")
        })
        return _obj





# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import py_gitea_opensuse_org
from py_gitea_opensuse_org.api.activitypub_api import ActivitypubApi  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestActivitypubApi(unittest.TestCase):
    """ActivitypubApi unit test stubs"""

    def setUp(self):
        self.api = (
            py_gitea_opensuse_org.api.activitypub_api.ActivitypubApi()
        )  # noqa: E501

    def tearDown(self):
        pass

    def test_activitypub_person(self):
        """Test case for activitypub_person

        Returns the Person actor for a user  # noqa: E501
        """
        pass

    def test_activitypub_person_inbox(self):
        """Test case for activitypub_person_inbox

        Send to the inbox  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Gitea API

    This documentation describes the Gitea API.

    The version of the OpenAPI document: 1.24.4
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.24.4"

# Define package exports
__all__ = [
    "ActivitypubApi",
    "AdminApi",
    "IssueApi",
    "MiscellaneousApi",
    "NotificationApi",
    "OrganizationApi",
    "PackageApi",
    "RepositoryApi",
    "SettingsApi",
    "UserApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "APIError",
    "AccessToken",
    "ActionArtifact",
    "ActionArtifactsResponse",
    "ActionRunner",
    "ActionRunnerLabel",
    "ActionRunnersResponse",
    "ActionTask",
    "ActionTaskResponse",
    "ActionVariable",
    "ActionWorkflow",
    "ActionWorkflowResponse",
    "ActionWorkflowRun",
    "Activity",
    "ActivityPub",
    "AddCollaboratorOption",
    "AddTimeOption",
    "AnnotatedTag",
    "AnnotatedTagObject",
    "Attachment",
    "Badge",
    "Branch",
    "BranchProtection",
    "ChangeFileOperation",
    "ChangeFilesOptions",
    "ChangedFile",
    "CombinedStatus",
    "Comment",
    "Commit",
    "CommitAffectedFiles",
    "CommitDateOptions",
    "CommitMeta",
    "CommitStats",
    "CommitStatus",
    "CommitUser",
    "Compare",
    "ContentsResponse",
    "CreateAccessTokenOption",
    "CreateActionWorkflowDispatch",
    "CreateBranchProtectionOption",
    "CreateBranchRepoOption",
    "CreateEmailOption",
    "CreateFileOptions",
    "CreateForkOption",
    "CreateGPGKeyOption",
    "CreateHookOption",
    "CreateIssueCommentOption",
    "CreateIssueOption",
    "CreateKeyOption",
    "CreateLabelOption",
    "CreateMilestoneOption",
    "CreateOAuth2ApplicationOptions",
    "CreateOrUpdateSecretOption",
    "CreateOrgOption",
    "CreatePullRequestOption",
    "CreatePullReviewComment",
    "CreatePullReviewOptions",
    "CreatePushMirrorOption",
    "CreateReleaseOption",
    "CreateRepoOption",
    "CreateStatusOption",
    "CreateTagOption",
    "CreateTagProtectionOption",
    "CreateTeamOption",
    "CreateUserOption",
    "CreateVariableOption",
    "CreateWikiPageOptions",
    "Cron",
    "DeleteEmailOption",
    "DeleteFileOptions",
    "DeployKey",
    "DismissPullReviewOptions",
    "EditAttachmentOptions",
    "EditBranchProtectionOption",
    "EditDeadlineOption",
    "EditGitHookOption",
    "EditHookOption",
    "EditIssueCommentOption",
    "EditIssueOption",
    "EditLabelOption",
    "EditMilestoneOption",
    "EditOrgOption",
    "EditPullRequestOption",
    "EditReactionOption",
    "EditReleaseOption",
    "EditRepoOption",
    "EditTagProtectionOption",
    "EditTeamOption",
    "EditUserOption",
    "Email",
    "ExternalTracker",
    "ExternalWiki",
    "FileCommitResponse",
    "FileDeleteResponse",
    "FileLinksResponse",
    "FileResponse",
    "FilesResponse",
    "GPGKey",
    "GPGKeyEmail",
    "GeneralAPISettings",
    "GeneralAttachmentSettings",
    "GeneralRepoSettings",
    "GeneralUISettings",
    "GenerateRepoOption",
    "GetFilesOptions",
    "GitBlobResponse",
    "GitEntry",
    "GitHook",
    "GitObject",
    "GitTreeResponse",
    "GitignoreTemplateInfo",
    "Hook",
    "Identity",
    "InternalTracker",
    "Issue",
    "IssueConfig",
    "IssueConfigContactLink",
    "IssueConfigValidation",
    "IssueDeadline",
    "IssueFormField",
    "IssueLabelsOption",
    "IssueMeta",
    "IssueTemplate",
    "Label",
    "LabelTemplate",
    "LicenseTemplateInfo",
    "LicensesTemplateListEntry",
    "LockIssueOption",
    "MarkdownOption",
    "MarkupOption",
    "MergePullRequestOption",
    "MergeUpstreamRequest",
    "MergeUpstreamResponse",
    "MigrateRepoOptions",
    "Milestone",
    "NewIssuePinsAllowed",
    "NodeInfo",
    "NodeInfoServices",
    "NodeInfoSoftware",
    "NodeInfoUsage",
    "NodeInfoUsageUsers",
    "Note",
    "NotificationCount",
    "NotificationSubject",
    "NotificationThread",
    "OAuth2Application",
    "Organization",
    "OrganizationPermissions",
    "PRBranchInfo",
    "Package",
    "PackageFile",
    "PayloadCommit",
    "PayloadCommitVerification",
    "PayloadUser",
    "Permission",
    "PublicKey",
    "PullRequest",
    "PullRequestMeta",
    "PullReview",
    "PullReviewComment",
    "PullReviewRequestOptions",
    "PushMirror",
    "Reaction",
    "Reference",
    "Release",
    "RenameOrgOption",
    "RenameUserOption",
    "RepoCollaboratorPermission",
    "RepoCommit",
    "RepoCreateReleaseAttachmentRequest",
    "RepoTopicOptions",
    "RepoTransfer",
    "Repository",
    "RepositoryMeta",
    "SearchResults",
    "Secret",
    "ServerVersion",
    "StopWatch",
    "SubmitPullReviewOptions",
    "Tag",
    "TagProtection",
    "Team",
    "TeamSearch200Response",
    "TimelineComment",
    "TopicName",
    "TopicResponse",
    "TrackedTime",
    "TransferRepoOption",
    "UpdateBranchProtectionPriories",
    "UpdateBranchRepoOption",
    "UpdateFileOptions",
    "UpdateRepoAvatarOption",
    "UpdateUserAvatarOption",
    "UpdateVariableOption",
    "User",
    "UserBadgeOption",
    "UserHeatmapData",
    "UserSearch200Response",
    "UserSettings",
    "UserSettingsOptions",
    "WatchInfo",
    "WikiCommit",
    "WikiCommitList",
    "WikiPage",
    "WikiPageMetaData",
]

# import apis into sdk package
from py_gitea_opensuse_org.api.activitypub_api import ActivitypubApi as ActivitypubApi
from py_gitea_opensuse_org.api.admin_api import AdminApi as AdminApi
from py_gitea_opensuse_org.api.issue_api import IssueApi as IssueApi
from py_gitea_opensuse_org.api.miscellaneous_api import MiscellaneousApi as MiscellaneousApi
from py_gitea_opensuse_org.api.notification_api import NotificationApi as NotificationApi
from py_gitea_opensuse_org.api.organization_api import OrganizationApi as OrganizationApi
from py_gitea_opensuse_org.api.package_api import PackageApi as PackageApi
from py_gitea_opensuse_org.api.repository_api import RepositoryApi as RepositoryApi
from py_gitea_opensuse_org.api.settings_api import SettingsApi as SettingsApi
from py_gitea_opensuse_org.api.user_api import UserApi as UserApi

# import ApiClient
from py_gitea_opensuse_org.api_response import ApiResponse as ApiResponse
from py_gitea_opensuse_org.api_client import ApiClient as ApiClient
from py_gitea_opensuse_org.configuration import Configuration as Configuration
from py_gitea_opensuse_org.exceptions import OpenApiException as OpenApiException
from py_gitea_opensuse_org.exceptions import ApiTypeError as ApiTypeError
from py_gitea_opensuse_org.exceptions import ApiValueError as ApiValueError
from py_gitea_opensuse_org.exceptions import ApiKeyError as ApiKeyError
from py_gitea_opensuse_org.exceptions import ApiAttributeError as ApiAttributeError
from py_gitea_opensuse_org.exceptions import ApiException as ApiException

# import models into sdk package
from py_gitea_opensuse_org.models.api_error import APIError as APIError
from py_gitea_opensuse_org.models.access_token import AccessToken as AccessToken
from py_gitea_opensuse_org.models.action_artifact import ActionArtifact as ActionArtifact
from py_gitea_opensuse_org.models.action_artifacts_response import ActionArtifactsResponse as ActionArtifactsResponse
from py_gitea_opensuse_org.models.action_runner import ActionRunner as ActionRunner
from py_gitea_opensuse_org.models.action_runner_label import ActionRunnerLabel as ActionRunnerLabel
from py_gitea_opensuse_org.models.action_runners_response import ActionRunnersResponse as ActionRunnersResponse
from py_gitea_opensuse_org.models.action_task import ActionTask as ActionTask
from py_gitea_opensuse_org.models.action_task_response import ActionTaskResponse as ActionTaskResponse
from py_gitea_opensuse_org.models.action_variable import ActionVariable as ActionVariable
from py_gitea_opensuse_org.models.action_workflow import ActionWorkflow as ActionWorkflow
from py_gitea_opensuse_org.models.action_workflow_response import ActionWorkflowResponse as ActionWorkflowResponse
from py_gitea_opensuse_org.models.action_workflow_run import ActionWorkflowRun as ActionWorkflowRun
from py_gitea_opensuse_org.models.activity import Activity as Activity
from py_gitea_opensuse_org.models.activity_pub import ActivityPub as ActivityPub
from py_gitea_opensuse_org.models.add_collaborator_option import AddCollaboratorOption as AddCollaboratorOption
from py_gitea_opensuse_org.models.add_time_option import AddTimeOption as AddTimeOption
from py_gitea_opensuse_org.models.annotated_tag import AnnotatedTag as AnnotatedTag
from py_gitea_opensuse_org.models.annotated_tag_object import AnnotatedTagObject as AnnotatedTagObject
from py_gitea_opensuse_org.models.attachment import Attachment as Attachment
from py_gitea_opensuse_org.models.badge import Badge as Badge
from py_gitea_opensuse_org.models.branch import Branch as Branch
from py_gitea_opensuse_org.models.branch_protection import BranchProtection as BranchProtection
from py_gitea_opensuse_org.models.change_file_operation import ChangeFileOperation as ChangeFileOperation
from py_gitea_opensuse_org.models.change_files_options import ChangeFilesOptions as ChangeFilesOptions
from py_gitea_opensuse_org.models.changed_file import ChangedFile as ChangedFile
from py_gitea_opensuse_org.models.combined_status import CombinedStatus as CombinedStatus
from py_gitea_opensuse_org.models.comment import Comment as Comment
from py_gitea_opensuse_org.models.commit import Commit as Commit
from py_gitea_opensuse_org.models.commit_affected_files import CommitAffectedFiles as CommitAffectedFiles
from py_gitea_opensuse_org.models.commit_date_options import CommitDateOptions as CommitDateOptions
from py_gitea_opensuse_org.models.commit_meta import CommitMeta as CommitMeta
from py_gitea_opensuse_org.models.commit_stats import CommitStats as CommitStats
from py_gitea_opensuse_org.models.commit_status import CommitStatus as CommitStatus
from py_gitea_opensuse_org.models.commit_user import CommitUser as CommitUser
from py_gitea_opensuse_org.models.compare import Compare as Compare
from py_gitea_opensuse_org.models.contents_response import ContentsResponse as ContentsResponse
from py_gitea_opensuse_org.models.create_access_token_option import CreateAccessTokenOption as CreateAccessTokenOption
from py_gitea_opensuse_org.models.create_action_workflow_dispatch import CreateActionWorkflowDispatch as CreateActionWorkflowDispatch
from py_gitea_opensuse_org.models.create_branch_protection_option import CreateBranchProtectionOption as CreateBranchProtectionOption
from py_gitea_opensuse_org.models.create_branch_repo_option import CreateBranchRepoOption as CreateBranchRepoOption
from py_gitea_opensuse_org.models.create_email_option import CreateEmailOption as CreateEmailOption
from py_gitea_opensuse_org.models.create_file_options import CreateFileOptions as CreateFileOptions
from py_gitea_opensuse_org.models.create_fork_option import CreateForkOption as CreateForkOption
from py_gitea_opensuse_org.models.create_gpg_key_option import CreateGPGKeyOption as CreateGPGKeyOption
from py_gitea_opensuse_org.models.create_hook_option import CreateHookOption as CreateHookOption
from py_gitea_opensuse_org.models.create_issue_comment_option import CreateIssueCommentOption as CreateIssueCommentOption
from py_gitea_opensuse_org.models.create_issue_option import CreateIssueOption as CreateIssueOption
from py_gitea_opensuse_org.models.create_key_option import CreateKeyOption as CreateKeyOption
from py_gitea_opensuse_org.models.create_label_option import CreateLabelOption as CreateLabelOption
from py_gitea_opensuse_org.models.create_milestone_option import CreateMilestoneOption as CreateMilestoneOption
from py_gitea_opensuse_org.models.create_o_auth2_application_options import CreateOAuth2ApplicationOptions as CreateOAuth2ApplicationOptions
from py_gitea_opensuse_org.models.create_or_update_secret_option import CreateOrUpdateSecretOption as CreateOrUpdateSecretOption
from py_gitea_opensuse_org.models.create_org_option import CreateOrgOption as CreateOrgOption
from py_gitea_opensuse_org.models.create_pull_request_option import CreatePullRequestOption as CreatePullRequestOption
from py_gitea_opensuse_org.models.create_pull_review_comment import CreatePullReviewComment as CreatePullReviewComment
from py_gitea_opensuse_org.models.create_pull_review_options import CreatePullReviewOptions as CreatePullReviewOptions
from py_gitea_opensuse_org.models.create_push_mirror_option import CreatePushMirrorOption as CreatePushMirrorOption
from py_gitea_opensuse_org.models.create_release_option import CreateReleaseOption as CreateReleaseOption
from py_gitea_opensuse_org.models.create_repo_option import CreateRepoOption as CreateRepoOption
from py_gitea_opensuse_org.models.create_status_option import CreateStatusOption as CreateStatusOption
from py_gitea_opensuse_org.models.create_tag_option import CreateTagOption as CreateTagOption
from py_gitea_opensuse_org.models.create_tag_protection_option import CreateTagProtectionOption as CreateTagProtectionOption
from py_gitea_opensuse_org.models.create_team_option import CreateTeamOption as CreateTeamOption
from py_gitea_opensuse_org.models.create_user_option import CreateUserOption as CreateUserOption
from py_gitea_opensuse_org.models.create_variable_option import CreateVariableOption as CreateVariableOption
from py_gitea_opensuse_org.models.create_wiki_page_options import CreateWikiPageOptions as CreateWikiPageOptions
from py_gitea_opensuse_org.models.cron import Cron as Cron
from py_gitea_opensuse_org.models.delete_email_option import DeleteEmailOption as DeleteEmailOption
from py_gitea_opensuse_org.models.delete_file_options import DeleteFileOptions as DeleteFileOptions
from py_gitea_opensuse_org.models.deploy_key import DeployKey as DeployKey
from py_gitea_opensuse_org.models.dismiss_pull_review_options import DismissPullReviewOptions as DismissPullReviewOptions
from py_gitea_opensuse_org.models.edit_attachment_options import EditAttachmentOptions as EditAttachmentOptions
from py_gitea_opensuse_org.models.edit_branch_protection_option import EditBranchProtectionOption as EditBranchProtectionOption
from py_gitea_opensuse_org.models.edit_deadline_option import EditDeadlineOption as EditDeadlineOption
from py_gitea_opensuse_org.models.edit_git_hook_option import EditGitHookOption as EditGitHookOption
from py_gitea_opensuse_org.models.edit_hook_option import EditHookOption as EditHookOption
from py_gitea_opensuse_org.models.edit_issue_comment_option import EditIssueCommentOption as EditIssueCommentOption
from py_gitea_opensuse_org.models.edit_issue_option import EditIssueOption as EditIssueOption
from py_gitea_opensuse_org.models.edit_label_option import EditLabelOption as EditLabelOption
from py_gitea_opensuse_org.models.edit_milestone_option import EditMilestoneOption as EditMilestoneOption
from py_gitea_opensuse_org.models.edit_org_option import EditOrgOption as EditOrgOption
from py_gitea_opensuse_org.models.edit_pull_request_option import EditPullRequestOption as EditPullRequestOption
from py_gitea_opensuse_org.models.edit_reaction_option import EditReactionOption as EditReactionOption
from py_gitea_opensuse_org.models.edit_release_option import EditReleaseOption as EditReleaseOption
from py_gitea_opensuse_org.models.edit_repo_option import EditRepoOption as EditRepoOption
from py_gitea_opensuse_org.models.edit_tag_protection_option import EditTagProtectionOption as EditTagProtectionOption
from py_gitea_opensuse_org.models.edit_team_option import EditTeamOption as EditTeamOption
from py_gitea_opensuse_org.models.edit_user_option import EditUserOption as EditUserOption
from py_gitea_opensuse_org.models.email import Email as Email
from py_gitea_opensuse_org.models.external_tracker import ExternalTracker as ExternalTracker
from py_gitea_opensuse_org.models.external_wiki import ExternalWiki as ExternalWiki
from py_gitea_opensuse_org.models.file_commit_response import FileCommitResponse as FileCommitResponse
from py_gitea_opensuse_org.models.file_delete_response import FileDeleteResponse as FileDeleteResponse
from py_gitea_opensuse_org.models.file_links_response import FileLinksResponse as FileLinksResponse
from py_gitea_opensuse_org.models.file_response import FileResponse as FileResponse
from py_gitea_opensuse_org.models.files_response import FilesResponse as FilesResponse
from py_gitea_opensuse_org.models.gpg_key import GPGKey as GPGKey
from py_gitea_opensuse_org.models.gpg_key_email import GPGKeyEmail as GPGKeyEmail
from py_gitea_opensuse_org.models.general_api_settings import GeneralAPISettings as GeneralAPISettings
from py_gitea_opensuse_org.models.general_attachment_settings import GeneralAttachmentSettings as GeneralAttachmentSettings
from py_gitea_opensuse_org.models.general_repo_settings import GeneralRepoSettings as GeneralRepoSettings
from py_gitea_opensuse_org.models.general_ui_settings import GeneralUISettings as GeneralUISettings
from py_gitea_opensuse_org.models.generate_repo_option import GenerateRepoOption as GenerateRepoOption
from py_gitea_opensuse_org.models.get_files_options import GetFilesOptions as GetFilesOptions
from py_gitea_opensuse_org.models.git_blob_response import GitBlobResponse as GitBlobResponse
from py_gitea_opensuse_org.models.git_entry import GitEntry as GitEntry
from py_gitea_opensuse_org.models.git_hook import GitHook as GitHook
from py_gitea_opensuse_org.models.git_object import GitObject as GitObject
from py_gitea_opensuse_org.models.git_tree_response import GitTreeResponse as GitTreeResponse
from py_gitea_opensuse_org.models.gitignore_template_info import GitignoreTemplateInfo as GitignoreTemplateInfo
from py_gitea_opensuse_org.models.hook import Hook as Hook
from py_gitea_opensuse_org.models.identity import Identity as Identity
from py_gitea_opensuse_org.models.internal_tracker import InternalTracker as InternalTracker
from py_gitea_opensuse_org.models.issue import Issue as Issue
from py_gitea_opensuse_org.models.issue_config import IssueConfig as IssueConfig
from py_gitea_opensuse_org.models.issue_config_contact_link import IssueConfigContactLink as IssueConfigContactLink
from py_gitea_opensuse_org.models.issue_config_validation import IssueConfigValidation as IssueConfigValidation
from py_gitea_opensuse_org.models.issue_deadline import IssueDeadline as IssueDeadline
from py_gitea_opensuse_org.models.issue_form_field import IssueFormField as IssueFormField
from py_gitea_opensuse_org.models.issue_labels_option import IssueLabelsOption as IssueLabelsOption
from py_gitea_opensuse_org.models.issue_meta import IssueMeta as IssueMeta
from py_gitea_opensuse_org.models.issue_template import IssueTemplate as IssueTemplate
from py_gitea_opensuse_org.models.label import Label as Label
from py_gitea_opensuse_org.models.label_template import LabelTemplate as LabelTemplate
from py_gitea_opensuse_org.models.license_template_info import LicenseTemplateInfo as LicenseTemplateInfo
from py_gitea_opensuse_org.models.licenses_template_list_entry import LicensesTemplateListEntry as LicensesTemplateListEntry
from py_gitea_opensuse_org.models.lock_issue_option import LockIssueOption as LockIssueOption
from py_gitea_opensuse_org.models.markdown_option import MarkdownOption as MarkdownOption
from py_gitea_opensuse_org.models.markup_option import MarkupOption as MarkupOption
from py_gitea_opensuse_org.models.merge_pull_request_option import MergePullRequestOption as MergePullRequestOption
from py_gitea_opensuse_org.models.merge_upstream_request import MergeUpstreamRequest as MergeUpstreamRequest
from py_gitea_opensuse_org.models.merge_upstream_response import MergeUpstreamResponse as MergeUpstreamResponse
from py_gitea_opensuse_org.models.migrate_repo_options import MigrateRepoOptions as MigrateRepoOptions
from py_gitea_opensuse_org.models.milestone import Milestone as Milestone
from py_gitea_opensuse_org.models.new_issue_pins_allowed import NewIssuePinsAllowed as NewIssuePinsAllowed
from py_gitea_opensuse_org.models.node_info import NodeInfo as NodeInfo
from py_gitea_opensuse_org.models.node_info_services import NodeInfoServices as NodeInfoServices
from py_gitea_opensuse_org.models.node_info_software import NodeInfoSoftware as NodeInfoSoftware
from py_gitea_opensuse_org.models.node_info_usage import NodeInfoUsage as NodeInfoUsage
from py_gitea_opensuse_org.models.node_info_usage_users import NodeInfoUsageUsers as NodeInfoUsageUsers
from py_gitea_opensuse_org.models.note import Note as Note
from py_gitea_opensuse_org.models.notification_count import NotificationCount as NotificationCount
from py_gitea_opensuse_org.models.notification_subject import NotificationSubject as NotificationSubject
from py_gitea_opensuse_org.models.notification_thread import NotificationThread as NotificationThread
from py_gitea_opensuse_org.models.o_auth2_application import OAuth2Application as OAuth2Application
from py_gitea_opensuse_org.models.organization import Organization as Organization
from py_gitea_opensuse_org.models.organization_permissions import OrganizationPermissions as OrganizationPermissions
from py_gitea_opensuse_org.models.pr_branch_info import PRBranchInfo as PRBranchInfo
from py_gitea_opensuse_org.models.package import Package as Package
from py_gitea_opensuse_org.models.package_file import PackageFile as PackageFile
from py_gitea_opensuse_org.models.payload_commit import PayloadCommit as PayloadCommit
from py_gitea_opensuse_org.models.payload_commit_verification import PayloadCommitVerification as PayloadCommitVerification
from py_gitea_opensuse_org.models.payload_user import PayloadUser as PayloadUser
from py_gitea_opensuse_org.models.permission import Permission as Permission
from py_gitea_opensuse_org.models.public_key import PublicKey as PublicKey
from py_gitea_opensuse_org.models.pull_request import PullRequest as PullRequest
from py_gitea_opensuse_org.models.pull_request_meta import PullRequestMeta as PullRequestMeta
from py_gitea_opensuse_org.models.pull_review import PullReview as PullReview
from py_gitea_opensuse_org.models.pull_review_comment import PullReviewComment as PullReviewComment
from py_gitea_opensuse_org.models.pull_review_request_options import PullReviewRequestOptions as PullReviewRequestOptions
from py_gitea_opensuse_org.models.push_mirror import PushMirror as PushMirror
from py_gitea_opensuse_org.models.reaction import Reaction as Reaction
from py_gitea_opensuse_org.models.reference import Reference as Reference
from py_gitea_opensuse_org.models.release import Release as Release
from py_gitea_opensuse_org.models.rename_org_option import RenameOrgOption as RenameOrgOption
from py_gitea_opensuse_org.models.rename_user_option import RenameUserOption as RenameUserOption
from py_gitea_opensuse_org.models.repo_collaborator_permission import RepoCollaboratorPermission as RepoCollaboratorPermission
from py_gitea_opensuse_org.models.repo_commit import RepoCommit as RepoCommit
from py_gitea_opensuse_org.models.repo_create_release_attachment_request import RepoCreateReleaseAttachmentRequest as RepoCreateReleaseAttachmentRequest
from py_gitea_opensuse_org.models.repo_topic_options import RepoTopicOptions as RepoTopicOptions
from py_gitea_opensuse_org.models.repo_transfer import RepoTransfer as RepoTransfer
from py_gitea_opensuse_org.models.repository import Repository as Repository
from py_gitea_opensuse_org.models.repository_meta import RepositoryMeta as RepositoryMeta
from py_gitea_opensuse_org.models.search_results import SearchResults as SearchResults
from py_gitea_opensuse_org.models.secret import Secret as Secret
from py_gitea_opensuse_org.models.server_version import ServerVersion as ServerVersion
from py_gitea_opensuse_org.models.stop_watch import StopWatch as StopWatch
from py_gitea_opensuse_org.models.submit_pull_review_options import SubmitPullReviewOptions as SubmitPullReviewOptions
from py_gitea_opensuse_org.models.tag import Tag as Tag
from py_gitea_opensuse_org.models.tag_protection import TagProtection as TagProtection
from py_gitea_opensuse_org.models.team import Team as Team
from py_gitea_opensuse_org.models.team_search200_response import TeamSearch200Response as TeamSearch200Response
from py_gitea_opensuse_org.models.timeline_comment import TimelineComment as TimelineComment
from py_gitea_opensuse_org.models.topic_name import TopicName as TopicName
from py_gitea_opensuse_org.models.topic_response import TopicResponse as TopicResponse
from py_gitea_opensuse_org.models.tracked_time import TrackedTime as TrackedTime
from py_gitea_opensuse_org.models.transfer_repo_option import TransferRepoOption as TransferRepoOption
from py_gitea_opensuse_org.models.update_branch_protection_priories import UpdateBranchProtectionPriories as UpdateBranchProtectionPriories
from py_gitea_opensuse_org.models.update_branch_repo_option import UpdateBranchRepoOption as UpdateBranchRepoOption
from py_gitea_opensuse_org.models.update_file_options import UpdateFileOptions as UpdateFileOptions
from py_gitea_opensuse_org.models.update_repo_avatar_option import UpdateRepoAvatarOption as UpdateRepoAvatarOption
from py_gitea_opensuse_org.models.update_user_avatar_option import UpdateUserAvatarOption as UpdateUserAvatarOption
from py_gitea_opensuse_org.models.update_variable_option import UpdateVariableOption as UpdateVariableOption
from py_gitea_opensuse_org.models.user import User as User
from py_gitea_opensuse_org.models.user_badge_option import UserBadgeOption as UserBadgeOption
from py_gitea_opensuse_org.models.user_heatmap_data import UserHeatmapData as UserHeatmapData
from py_gitea_opensuse_org.models.user_search200_response import UserSearch200Response as UserSearch200Response
from py_gitea_opensuse_org.models.user_settings import UserSettings as UserSettings
from py_gitea_opensuse_org.models.user_settings_options import UserSettingsOptions as UserSettingsOptions
from py_gitea_opensuse_org.models.watch_info import WatchInfo as WatchInfo
from py_gitea_opensuse_org.models.wiki_commit import WikiCommit as WikiCommit
from py_gitea_opensuse_org.models.wiki_commit_list import WikiCommitList as WikiCommitList
from py_gitea_opensuse_org.models.wiki_page import WikiPage as WikiPage
from py_gitea_opensuse_org.models.wiki_page_meta_data import WikiPageMetaData as WikiPageMetaData



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import py_gitea_opensuse_org
from py_gitea_opensuse_org.api.user_api import UserApi  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = py_gitea_opensuse_org.api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_current_user_repo(self):
        """Test case for create_current_user_repo

        Create a repository  # noqa: E501
        """
        pass

    def test_get_user_settings(self):
        """Test case for get_user_settings

        Get user settings  # noqa: E501
        """
        pass

    def test_get_verification_token(self):
        """Test case for get_verification_token

        Get a Token to verify  # noqa: E501
        """
        pass

    def test_update_user_settings(self):
        """Test case for update_user_settings

        Update user settings  # noqa: E501
        """
        pass

    def test_user_add_email(self):
        """Test case for user_add_email

        Add email addresses  # noqa: E501
        """
        pass

    def test_user_check_following(self):
        """Test case for user_check_following

        Check if one user is following another user  # noqa: E501
        """
        pass

    def test_user_create_o_auth2_application(self):
        """Test case for user_create_o_auth2_application

        creates a new OAuth2 application  # noqa: E501
        """
        pass

    def test_user_create_token(self):
        """Test case for user_create_token

        Create an access token  # noqa: E501
        """
        pass

    def test_user_current_check_following(self):
        """Test case for user_current_check_following

        Check whether a user is followed by the authenticated user  # noqa: E501
        """
        pass

    def test_user_current_check_starring(self):
        """Test case for user_current_check_starring

        Whether the authenticated is starring the repo  # noqa: E501
        """
        pass

    def test_user_current_delete_follow(self):
        """Test case for user_current_delete_follow

        Unfollow a user  # noqa: E501
        """
        pass

    def test_user_current_delete_gpg_key(self):
        """Test case for user_current_delete_gpg_key

        Remove a GPG key  # noqa: E501
        """
        pass

    def test_user_current_delete_key(self):
        """Test case for user_current_delete_key

        Delete a public key  # noqa: E501
        """
        pass

    def test_user_current_delete_star(self):
        """Test case for user_current_delete_star

        Unstar the given repo  # noqa: E501
        """
        pass

    def test_user_current_get_gpg_key(self):
        """Test case for user_current_get_gpg_key

        Get a GPG key  # noqa: E501
        """
        pass

    def test_user_current_get_key(self):
        """Test case for user_current_get_key

        Get a public key  # noqa: E501
        """
        pass

    def test_user_current_list_followers(self):
        """Test case for user_current_list_followers

        List the authenticated user's followers  # noqa: E501
        """
        pass

    def test_user_current_list_following(self):
        """Test case for user_current_list_following

        List the users that the authenticated user is following  # noqa: E501
        """
        pass

    def test_user_current_list_gpg_keys(self):
        """Test case for user_current_list_gpg_keys

        List the authenticated user's GPG keys  # noqa: E501
        """
        pass

    def test_user_current_list_keys(self):
        """Test case for user_current_list_keys

        List the authenticated user's public keys  # noqa: E501
        """
        pass

    def test_user_current_list_repos(self):
        """Test case for user_current_list_repos

        List the repos that the authenticated user owns  # noqa: E501
        """
        pass

    def test_user_current_list_starred(self):
        """Test case for user_current_list_starred

        The repos that the authenticated user has starred  # noqa: E501
        """
        pass

    def test_user_current_list_subscriptions(self):
        """Test case for user_current_list_subscriptions

        List repositories watched by the authenticated user  # noqa: E501
        """
        pass

    def test_user_current_post_gpg_key(self):
        """Test case for user_current_post_gpg_key

        Create a GPG key  # noqa: E501
        """
        pass

    def test_user_current_post_key(self):
        """Test case for user_current_post_key

        Create a public key  # noqa: E501
        """
        pass

    def test_user_current_put_follow(self):
        """Test case for user_current_put_follow

        Follow a user  # noqa: E501
        """
        pass

    def test_user_current_put_star(self):
        """Test case for user_current_put_star

        Star the given repo  # noqa: E501
        """
        pass

    def test_user_current_tracked_times(self):
        """Test case for user_current_tracked_times

        List the current user's tracked times  # noqa: E501
        """
        pass

    def test_user_delete_access_token(self):
        """Test case for user_delete_access_token

        delete an access token  # noqa: E501
        """
        pass

    def test_user_delete_email(self):
        """Test case for user_delete_email

        Delete email addresses  # noqa: E501
        """
        pass

    def test_user_delete_o_auth2_application(self):
        """Test case for user_delete_o_auth2_application

        delete an OAuth2 Application  # noqa: E501
        """
        pass

    def test_user_get(self):
        """Test case for user_get

        Get a user  # noqa: E501
        """
        pass

    def test_user_get_current(self):
        """Test case for user_get_current

        Get the authenticated user  # noqa: E501
        """
        pass

    def test_user_get_heatmap_data(self):
        """Test case for user_get_heatmap_data

        Get a user's heatmap  # noqa: E501
        """
        pass

    def test_user_get_o_auth2_application(self):
        """Test case for user_get_o_auth2_application

        get an OAuth2 Application  # noqa: E501
        """
        pass

    def test_user_get_oauth2_application(self):
        """Test case for user_get_oauth2_application

        List the authenticated user's oauth2 applications  # noqa: E501
        """
        pass

    def test_user_get_stop_watches(self):
        """Test case for user_get_stop_watches

        Get list of all existing stopwatches  # noqa: E501
        """
        pass

    def test_user_get_tokens(self):
        """Test case for user_get_tokens

        List the authenticated user's access tokens  # noqa: E501
        """
        pass

    def test_user_list_emails(self):
        """Test case for user_list_emails

        List the authenticated user's email addresses  # noqa: E501
        """
        pass

    def test_user_list_followers(self):
        """Test case for user_list_followers

        List the given user's followers  # noqa: E501
        """
        pass

    def test_user_list_following(self):
        """Test case for user_list_following

        List the users that the given user is following  # noqa: E501
        """
        pass

    def test_user_list_gpg_keys(self):
        """Test case for user_list_gpg_keys

        List the given user's GPG keys  # noqa: E501
        """
        pass

    def test_user_list_keys(self):
        """Test case for user_list_keys

        List the given user's public keys  # noqa: E501
        """
        pass

    def test_user_list_repos(self):
        """Test case for user_list_repos

        List the repos owned by the given user  # noqa: E501
        """
        pass

    def test_user_list_starred(self):
        """Test case for user_list_starred

        The repos that the given user has starred  # noqa: E501
        """
        pass

    def test_user_list_subscriptions(self):
        """Test case for user_list_subscriptions

        List the repositories watched by a user  # noqa: E501
        """
        pass

    def test_user_list_teams(self):
        """Test case for user_list_teams

        List all the teams a user belongs to  # noqa: E501
        """
        pass

    def test_user_search(self):
        """Test case for user_search

        Search for users  # noqa: E501
        """
        pass

    def test_user_update_o_auth2_application(self):
        """Test case for user_update_o_auth2_application

        update an OAuth2 Application, this includes regenerating the client secret  # noqa: E501
        """
        pass

    def test_user_verify_gpg_key(self):
        """Test case for user_verify_gpg_key

        Verify a GPG key  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Gitea API.

    This documentation describes the Gitea API.  # noqa: E501

    The version of the OpenAPI document: 1.19.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import py_gitea_opensuse_org
from py_gitea_opensuse_org.api.settings_api import SettingsApi  # noqa: E501
from py_gitea_opensuse_org.rest import ApiException


class TestSettingsApi(unittest.TestCase):
    """SettingsApi unit test stubs"""

    def setUp(self):
        self.api = py_gitea_opensuse_org.api.settings_api.SettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_general_api_settings(self):
        """Test case for get_general_api_settings

        Get instance's global settings for api  # noqa: E501
        """
        pass

    def test_get_general_attachment_settings(self):
        """Test case for get_general_attachment_settings

        Get instance's global settings for Attachment  # noqa: E501
        """
        pass

    def test_get_general_repository_settings(self):
        """Test case for get_general_repository_settings

        Get instance's global settings for repositories  # noqa: E501
        """
        pass

    def test_get_general_ui_settings(self):
        """Test case for get_general_ui_settings

        Get instance's global settings for ui  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
